autowisp.database.data_model.provenance.camera module — AutoWISP documentation

# autowisp.database.data_model.provenance.camera module

## Class Inheritance Diagram

Define the camera dataset table for the pipeline

class autowisp.database.data_model.provenance.camera.Camera(**kwargs)

  Bases: `DataModelBase`

  The table describing the camera specified

  __str__()

    Human readable info for the camera.

  camera_type
  camera_type_id

    The id of the camera type

  channels
  id

    A unique identifier for each row.

  notes

    The notes provided for the camera

  observers
  observing_sessions
  serial_number

    The serial number of the camera

  timestamp

    When record was last changed